[testenv:test]
description = run the distribution tests
use_develop = {[base]use_develop}
skip_install = {[base]skip_install}
constrain_package_deps = {[base]constrain_package_deps}
set_env = {[base]set_env}
deps =
    {[test_runner]deps}
    %(single_constraints_file)s
    %(test_deps_additional)s
commands = {[test_runner]test}
extras = {[base]extras}
%(testenv_options)s

[testenv]
description = run the distribution tests (generative environments)
use_develop = {[base]use_develop}
skip_install = {[base]skip_install}
constrain_package_deps = {[base]constrain_package_deps}
set_env = {[base]set_env}
deps = {[base]deps}
commands = {[test_runner]test}
extras = {[base]extras}
%(testenv_options)s

[testenv:coverage]
description = get a test coverage report
use_develop = {[base]use_develop}
skip_install = {[base]skip_install}
constrain_package_deps = {[base]constrain_package_deps}
set_env = {[base]set_env}
deps =
    {[test_runner]deps}
    coverage
    %(single_constraints_file)s
    %(test_deps_additional)s
commands = {[test_runner]coverage}
extras = {[base]extras}
%(testenv_options)s
